@@ -84,15 +84,22 @@ def for_each_variable(
         variable_entity = entity.entity.get_variable(variable).entity
         if variable_entity.key == entity.entity.key:
             values = entity(variable, period, options=options)
-        else:
-            try:
-                values = group_agg_func(
-                    entity.members(variable, period, options=options)
-                )
-            except VariableNotFoundError as e:
-                raise Exception(
-                    f"Variable {variable} is not defined for {entity.entity.label} or {entity.entity.label} members: {e}"
-                )
+        elif variable_entity.is_person:
+            values = group_agg_func(
+                entity.members(variable, period, options=options)
+            )
+        elif entity.entity.is_person:
+            raise ValueError(
+                f"You requested to aggregate {variable} (defined for {variable_entity.plural}) to {entity.entity.plural}, but this is not yet implemented."
+            )
+        else:  # Group-to-group aggregation
+            variable_population = entity.simulation.populations[
+                variable_entity.key
+            ]
+            person_shares = variable_population.project(
+                variable_population(variable, period)
+            ) / variable_population.project(variable_population.nb_persons())
+            values = entity.sum(person_shares)
         if result is None:
             result = values
         else:
